@@ -21,6 +21,6 @@ import click
 def no_ldap(ctx):
     """(lftools-uv[ldap]) Provides an ldap interface.
 
-    To activate this interface run `pip install lftools-uv[ldap]`.
+    To activate this interface run `uv pip install "lftools-uv[ldap]"`.
     """
     pass
