@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: EPL-1.0
 ##############################################################################
 # Copyright (c) 2017 The Linux Foundation and others.
@@ -16,7 +15,6 @@ import errno
 import fnmatch
 import glob
 import gzip
-import io
 import logging
 import math
 import mimetypes
@@ -31,7 +29,6 @@ from pathlib import Path
 
 import boto3
 import requests
-import six
 from botocore.exceptions import ClientError
 from defusedxml.minidom import parseString
 
@@ -58,12 +55,12 @@ def _compress_text(dir):
     for _file in paths:
         # glob may follow symlink paths that open can't find
         if os.path.exists(_file):
-            log.debug("Compressing file {}".format(_file))
-            with open(_file, "rb") as src, gzip.open("{}.gz".format(_file), "wb") as dest:
+            log.debug(f"Compressing file {_file}")
+            with open(_file, "rb") as src, gzip.open(f"{_file}.gz", "wb") as dest:
                 shutil.copyfileobj(src, dest)
                 os.remove(_file)
         else:
-            log.info("Could not open path from glob {}".format(_file))
+            log.info(f"Could not open path from glob {_file}")
 
     os.chdir(save_dir)
 
@@ -72,7 +69,7 @@ def _format_url(url):
     """Ensure url starts with http and trim trailing '/'s."""
     start_pattern = re.compile("^(http|https)://")
     if not start_pattern.match(url):
-        url = "http://{}".format(url)
+        url = f"http://{url}"
 
     if url.endswith("/"):
         url = url.rstrip("/")
@@ -94,13 +91,13 @@ def _request_post(url, data, headers):
         resp = requests.post(url, data=data, headers=headers)
     except requests.exceptions.MissingSchema:
         log.debug("in _request_post. MissingSchema")
-        _log_error_and_exit("Not valid URL: {}".format(url))
+        _log_error_and_exit(f"Not valid URL: {url}")
     except requests.exceptions.ConnectionError:
         log.debug("in _request_post. ConnectionError")
-        _log_error_and_exit("Could not connect to URL: {}".format(url))
+        _log_error_and_exit(f"Could not connect to URL: {url}")
     except requests.exceptions.InvalidURL:
         log.debug("in _request_post. InvalidURL")
-        _log_error_and_exit("Invalid URL: {}".format(url))
+        _log_error_and_exit(f"Invalid URL: {url}")
     return resp
 
 
@@ -115,8 +112,8 @@ def _request_post_file(url, file_to_upload, parameters=None):
     resp = {}
     try:
         upload_file = open(file_to_upload, "rb")
-    except FileNotFoundError:
-        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), file_to_upload)
+    except FileNotFoundError as err:
+        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), file_to_upload) from err
 
     files = {"file": upload_file}
     try:
@@ -124,12 +121,12 @@ def _request_post_file(url, file_to_upload, parameters=None):
             resp = requests.post(url, data=parameters, files=files)
         else:
             resp = requests.post(url, data=upload_file.read())
-    except requests.exceptions.MissingSchema:
-        raise requests.HTTPError("Not valid URL: {}".format(url))
-    except requests.exceptions.ConnectionError:
-        raise requests.HTTPError("Could not connect to URL: {}".format(url))
-    except requests.exceptions.InvalidURL:
-        raise requests.HTTPError("Invalid URL: {}".format(url))
+    except requests.exceptions.MissingSchema as err:
+        raise requests.HTTPError(f"Not valid URL: {url}") from err
+    except requests.exceptions.ConnectionError as err:
+        raise requests.HTTPError(f"Could not connect to URL: {url}") from err
+    except requests.exceptions.InvalidURL as err:
+        raise requests.HTTPError(f"Invalid URL: {url}") from err
 
     if resp.status_code == 400:
         raise requests.HTTPError("Repository is read only")
@@ -138,9 +135,7 @@ def _request_post_file(url, file_to_upload, parameters=None):
 
     if not str(resp.status_code).startswith("20"):
         raise requests.HTTPError(
-            "Failed to upload to Nexus with status code: {}.\n{}\n{}".format(
-                resp.status_code, resp.text, file_to_upload
-            )
+            f"Failed to upload to Nexus with status code: {resp.status_code}.\n{resp.text}\n{file_to_upload}"
         )
 
     return resp
@@ -151,8 +146,8 @@ def _request_put_file(url, file_to_upload, parameters=None):
     resp = {}
     try:
         upload_file = open(file_to_upload, "rb")
-    except FileNotFoundError:
-        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), file_to_upload)
+    except FileNotFoundError as err:
+        raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), file_to_upload) from err
 
     files = {"file": upload_file}
     try:
@@ -160,18 +155,19 @@ def _request_put_file(url, file_to_upload, parameters=None):
             resp = requests.put(url, data=parameters, files=files)
         else:
             resp = requests.put(url, data=upload_file)
-    except requests.exceptions.MissingSchema:
-        raise requests.HTTPError("Not valid URL format. Check for https:// etc..: {}".format(url))
-    except requests.exceptions.ConnectTimeout:
-        raise requests.HTTPError("Timed out connecting to {}".format(url))
-    except requests.exceptions.ReadTimeout:
-        raise requests.HTTPError("Timed out waiting for the server to reply ({})".format(url))
-    except requests.exceptions.ConnectionError:
-        raise requests.HTTPError("A connection error occurred ({})".format(url))
-    except requests.exceptions.InvalidURL:
-        raise requests.HTTPError("Invalid URL format: {}".format(url))
-    except requests.RequestException as e:
-        log.error(e)
+    except requests.exceptions.MissingSchema as err:
+        raise requests.HTTPError(f"Not valid URL format. Check for https:// etc..: {url}") from err
+    except requests.exceptions.ConnectTimeout as err:
+        raise requests.HTTPError(f"Timed out connecting to {url}") from err
+    except requests.exceptions.ReadTimeout as err:
+        raise requests.HTTPError(f"Timed out waiting for the server to reply ({url})") from err
+    except requests.exceptions.ConnectionError as err:
+        raise requests.HTTPError(f"A connection error occurred ({url})") from err
+    except requests.exceptions.InvalidURL as err:
+        raise requests.HTTPError(f"Invalid URL format: {url}") from err
+    except requests.RequestException as err:
+        log.error(err)
+        raise requests.HTTPError(f"Request error during PUT to {url}") from err
 
     if resp.status_code == 201:
         return True
@@ -184,21 +180,19 @@ def _request_put_file(url, file_to_upload, parameters=None):
 
     if not str(resp.status_code).startswith("20"):
         raise requests.HTTPError(
-            "Failed to upload to Nexus with status code: {}.\n{}\n{}".format(
-                resp.status_code, resp.text, file_to_upload
-            )
+            f"Failed to upload to Nexus with status code: {resp.status_code}.\n{resp.text}\n{file_to_upload}"
         )
 
 
 def _get_node_from_xml(xml_data, tag_name):
     """Extract tag data from xml data."""
-    log.debug("xml={}".format(xml_data))
+    log.debug(f"xml={xml_data}")
 
     try:
         dom1 = parseString(xml_data)
         childnode = dom1.getElementsByTagName(tag_name)[0]
     except Exception:
-        _log_error_and_exit("Received bad XML, can not find tag {}".format(tag_name), xml_data)
+        _log_error_and_exit(f"Received bad XML, can not find tag {tag_name}", xml_data)
     return childnode.firstChild.data
 
 
@@ -211,7 +205,7 @@ def _remove_duplicates_and_sort(lst):
     for i in range(len(no_dups_lst)):
         if lst.count(no_dups_lst[i]) > 1:
             duplicated_list.append(no_dups_lst[i])
-    log.debug("duplicates  : {}".format(duplicated_list))
+    log.debug(f"duplicates  : {duplicated_list}")
 
     return no_dups_lst
 
@@ -235,25 +229,25 @@ def copy_archives(workspace, pattern=None):
     archives_dir = os.path.join(workspace, "archives")
     dest_dir = os.getcwd()
 
-    log.debug("Copying files from {} with pattern '{}' to {}.".format(workspace, pattern, dest_dir))
-    log.debug("archives_dir = {}".format(archives_dir))
+    log.debug(f"Copying files from {workspace} with pattern '{pattern}' to {dest_dir}.")
+    log.debug(f"archives_dir = {archives_dir}")
 
     if os.path.exists(archives_dir):
         if os.path.isfile(archives_dir):
-            log.error("Archives {} is a file, not a directory.".format(archives_dir))
+            log.error(f"Archives {archives_dir} is a file, not a directory.")
             raise OSError(errno.ENOENT, "Not a directory", archives_dir)
         else:
-            log.debug("Archives dir {} does exist.".format(archives_dir))
+            log.debug(f"Archives dir {archives_dir} does exist.")
             for file_or_dir in os.listdir(archives_dir):
                 f = os.path.join(archives_dir, file_or_dir)
                 try:
-                    log.debug("Moving {}".format(f))
+                    log.debug(f"Moving {f}")
                     shutil.move(f, dest_dir)
                 except shutil.Error as e:
                     log.error(e)
-                    raise OSError(errno.EPERM, "Could not move to", archives_dir)
+                    raise OSError(errno.EPERM, "Could not move to", archives_dir) from e
     else:
-        log.error("Archives dir {} does not exist.".format(archives_dir))
+        log.error(f"Archives dir {archives_dir} does not exist.")
         raise OSError(errno.ENOENT, "Missing directory", archives_dir)
 
     if pattern is None:
@@ -265,10 +259,10 @@ def copy_archives(workspace, pattern=None):
 
     # Debug: List all files in workspace for troubleshooting
     log.debug("Workspace contents before pattern matching:")
-    for root, dirs, files in os.walk(workspace):
+    for root, _dirs, files in os.walk(workspace):
         for file in files:
             rel_path = os.path.relpath(os.path.join(root, file), workspace)
-            log.debug("  {}".format(rel_path))
+            log.debug(f"  {rel_path}")
 
     # Use pathlib for more reliable pattern matching across Python versions
     workspace_path = Path(workspace)
@@ -277,14 +271,14 @@ def copy_archives(workspace, pattern=None):
         if p == "":  # Skip empty patterns as they are invalid
             continue
 
-        log.debug("Searching for pattern: {}".format(p))
+        log.debug(f"Searching for pattern: {p}")
 
         # Handle recursive patterns with pathlib.rglob() for better Python 3.8 compatibility
         if p.startswith("**/"):
             # Use rglob for recursive patterns like "**/*.txt"
             pattern_suffix = p[3:]  # Remove "**/" prefix
             found_paths = list(workspace_path.rglob(pattern_suffix))
-            log.debug("Using rglob for pattern '{}' -> rglob('{}')".format(p, pattern_suffix))
+            log.debug(f"Using rglob for pattern '{p}' -> rglob('{pattern_suffix}')")
         elif "**" in p:
             # For other recursive patterns, fall back to manual traversal with fnmatch
             found_paths = []
@@ -293,46 +287,46 @@ def copy_archives(workspace, pattern=None):
                     relative_path = file_path.relative_to(workspace_path)
                     if fnmatch.fnmatch(str(relative_path), p):
                         found_paths.append(file_path)
-            log.debug("Using fnmatch for complex pattern '{}'".format(p))
+            log.debug(f"Using fnmatch for complex pattern '{p}'")
         else:
             # For simple patterns without **, use glob
             found_paths = list(workspace_path.glob(p))
-            log.debug("Using glob for simple pattern '{}'".format(p))
+            log.debug(f"Using glob for simple pattern '{p}'")
 
         # Convert to absolute string paths
         absolute_paths = [str(path) for path in found_paths if path.is_file()]
-        log.debug("Found files for pattern '{}': {}".format(p, absolute_paths))
+        log.debug(f"Found files for pattern '{p}': {absolute_paths}")
         paths.extend(absolute_paths)
 
-    log.debug("Files found: {}".format(paths))
+    log.debug(f"Files found: {paths}")
 
     no_dups_paths = _remove_duplicates_and_sort(paths)
     for src in no_dups_paths:
         if len(os.path.basename(src)) > 255:
-            log.warn("Filename {} is over 255 characters. Skipping...".format(os.path.basename(src)))
+            log.warn(f"Filename {os.path.basename(src)} is over 255 characters. Skipping...")
 
         dest = os.path.join(dest_dir, src[len(workspace) + 1 :])
-        log.debug("{} -> {}".format(src, dest))
+        log.debug(f"{src} -> {dest}")
 
         if os.path.isfile(src):
             try:
                 shutil.move(src, dest)
-            except IOError as e:  # Switch to FileNotFoundError when Python 2 support is dropped.
-                log.debug("Missing path, will create it {}.\n{}".format(os.path.dirname(dest), e))
+            except OSError as e:  # Switch to FileNotFoundError when Python 2 support is dropped.
+                log.debug(f"Missing path, will create it {os.path.dirname(dest)}.\n{e}")
                 os.makedirs(os.path.dirname(dest))
                 shutil.move(src, dest)
         else:
-            log.info("Not copying directories: {}.".format(src))
+            log.info(f"Not copying directories: {src}.")
 
     # Create a temp file to handle empty dirs in AWS S3 buckets.
     if os.environ.get("S3_BUCKET") is not None:
         now = datetime.datetime.now()
         p = now.strftime("_%d%m%Y_%H%M%S_")
-        for dirpath, dirnames, files in os.walk(dest_dir):
+        for dirpath, _dirnames, files in os.walk(dest_dir):
             if not files:
                 fd, tmp = tempfile.mkstemp(prefix=p, dir=dirpath)
                 os.close(fd)
-                log.debug("temp file created in dir: {}.".format(dirpath))
+                log.debug(f"temp file created in dir: {dirpath}.")
 
 
 def deploy_archives(nexus_url, nexus_path, workspace, pattern=None):
@@ -361,13 +355,13 @@ def deploy_archives(nexus_url, nexus_path, workspace, pattern=None):
     previous_dir = os.getcwd()
     work_dir = tempfile.mkdtemp(prefix="lftools-da.")
     os.chdir(work_dir)
-    log.debug("workspace: {}, work_dir: {}".format(workspace, work_dir))
+    log.debug(f"workspace: {workspace}, work_dir: {work_dir}")
 
     copy_archives(workspace, pattern)
     _compress_text(work_dir)
 
-    archives_zip = shutil.make_archive("{}/archives".format(workspace), "zip")
-    log.debug("archives zip: {}".format(archives_zip))
+    archives_zip = shutil.make_archive(f"{workspace}/archives", "zip")
+    log.debug(f"archives zip: {archives_zip}")
     deploy_nexus_zip(nexus_url, "logs", nexus_path, archives_zip)
 
     os.chdir(previous_dir)
@@ -396,15 +390,15 @@ def deploy_logs(nexus_url, nexus_path, build_url):
     previous_dir = os.getcwd()
     work_dir = tempfile.mkdtemp(prefix="lftools-dl.")
     os.chdir(work_dir)
-    log.debug("work_dir: {}".format(work_dir))
+    log.debug(f"work_dir: {work_dir}")
 
     build_details = open("_build-details.log", "w+")
-    build_details.write("build-url: {}".format(build_url))
+    build_details.write(f"build-url: {build_url}")
 
     with open("_sys-info.log", "w+") as sysinfo_log:
         sys_cmds = []
 
-        log.debug("Platform: {}".format(sys.platform))
+        log.debug(f"Platform: {sys.platform}")
         if sys.platform == "linux" or sys.platform == "linux2":
             sys_cmds = [
                 ["uname", "-a"],
@@ -421,7 +415,7 @@ def deploy_logs(nexus_url, nexus_path, build_url):
             try:
                 output = subprocess.check_output(c).decode("utf-8")
             except FileNotFoundError:
-                log.debug("Command not found: {}".format(c))
+                log.debug(f"Command not found: {c}")
                 continue
 
             output = "---> {}:\n{}\n".format(" ".join(c), output)
@@ -434,20 +428,20 @@ def deploy_logs(nexus_url, nexus_path, build_url):
     MAGIC_STRING = "-----END_OF_BUILD-----"
     log.info(MAGIC_STRING)
 
-    resp = requests.get("{}/consoleText".format(_format_url(build_url)))
-    with io.open("console.log", "w+", encoding="utf-8") as f:
+    resp = requests.get(f"{_format_url(build_url)}/consoleText")
+    with open("console.log", "w+", encoding="utf-8") as f:
         f.write(str(resp.content.decode("utf-8").split(MAGIC_STRING)[0]))
 
-    resp = requests.get("{}/timestamps?time=HH:mm:ss&appendLog".format(_format_url(build_url)))
-    with io.open("console-timestamp.log", "w+", encoding="utf-8") as f:
+    resp = requests.get(f"{_format_url(build_url)}/timestamps?time=HH:mm:ss&appendLog")
+    with open("console-timestamp.log", "w+", encoding="utf-8") as f:
         f.write(str(resp.content.decode("utf-8").split(MAGIC_STRING)[0]))
 
     _compress_text(work_dir)
 
     console_zip = tempfile.NamedTemporaryFile(prefix="lftools-dl", delete=True)
-    log.debug("console-zip: {}".format(console_zip.name))
+    log.debug(f"console-zip: {console_zip.name}")
     shutil.make_archive(console_zip.name, "zip", work_dir)
-    deploy_nexus_zip(nexus_url, "logs", nexus_path, "{}.zip".format(console_zip.name))
+    deploy_nexus_zip(nexus_url, "logs", nexus_path, f"{console_zip.name}.zip")
     console_zip.close()
 
     os.chdir(previous_dir)
@@ -483,14 +477,14 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
         if file == "_tmpfile":
             for dir in (logs_dir, silo_dir, jenkins_node_dir):
                 try:
-                    s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(dir, file))
+                    s3.Bucket(s3_bucket).upload_file(file, f"{dir}{file}")
                 except ClientError as e:
                     log.error(e)
                     return False
                 return True
         if mimetypes.guess_type(file)[0] is None and mimetypes.guess_type(file)[1] is None:
             try:
-                s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(s3_path, file), ExtraArgs=extra_args)
+                s3.Bucket(s3_bucket).upload_file(file, f"{s3_path}{file}", ExtraArgs=extra_args)
             except ClientError as e:
                 log.error(e)
                 return False
@@ -498,7 +492,7 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
         elif mimetypes.guess_type(file)[0] is None or mimetypes.guess_type(file)[0] in "text/plain":
             extra_args = text_plain_extra_args
             try:
-                s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(s3_path, file), ExtraArgs=extra_args)
+                s3.Bucket(s3_bucket).upload_file(file, f"{s3_path}{file}", ExtraArgs=extra_args)
             except ClientError as e:
                 log.error(e)
                 return False
@@ -506,7 +500,7 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
         elif mimetypes.guess_type(file)[0] in "text/html":
             extra_args = text_html_extra_args
             try:
-                s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(s3_path, file), ExtraArgs=extra_args)
+                s3.Bucket(s3_bucket).upload_file(file, f"{s3_path}{file}", ExtraArgs=extra_args)
             except ClientError as e:
                 log.error(e)
                 return False
@@ -514,14 +508,14 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
         elif mimetypes.guess_type(file)[0] in "application/xml":
             extra_args = app_xml_extra_args
             try:
-                s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(s3_path, file), ExtraArgs=extra_args)
+                s3.Bucket(s3_bucket).upload_file(file, f"{s3_path}{file}", ExtraArgs=extra_args)
             except ClientError as e:
                 log.error(e)
                 return False
             return True
         else:
             try:
-                s3.Bucket(s3_bucket).upload_file(file, "{}{}".format(s3_path, file), ExtraArgs=extra_args)
+                s3.Bucket(s3_bucket).upload_file(file, f"{s3_path}{file}", ExtraArgs=extra_args)
             except ClientError as e:
                 log.error(e)
                 return False
@@ -536,19 +530,19 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
     silo_dir = s3_path.split("/")[1] + "/"
     jenkins_node_dir = logs_dir + silo_dir + s3_path.split("/")[2] + "/"
 
-    log.debug("work_dir: {}".format(work_dir))
+    log.debug(f"work_dir: {work_dir}")
 
     # Copy archive files to tmp dir
     copy_archives(workspace, pattern)
 
     # Create build logs
     build_details = open("_build-details.log", "w+")
-    build_details.write("build-url: {}".format(build_url))
+    build_details.write(f"build-url: {build_url}")
 
     with open("_sys-info.log", "w+") as sysinfo_log:
         sys_cmds = []
 
-        log.debug("Platform: {}".format(sys.platform))
+        log.debug(f"Platform: {sys.platform}")
         if sys.platform == "linux" or sys.platform == "linux2":
             sys_cmds = [
                 ["uname", "-a"],
@@ -565,7 +559,7 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
             try:
                 output = subprocess.check_output(c).decode("utf-8")
             except FileNotFoundError:
-                log.debug("Command not found: {}".format(c))
+                log.debug(f"Command not found: {c}")
                 continue
 
             output = "---> {}:\n{}\n".format(" ".join(c), output)
@@ -579,12 +573,12 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
     MAGIC_STRING = "-----END_OF_BUILD-----"
     log.info(MAGIC_STRING)
 
-    resp = requests.get("{}/consoleText".format(_format_url(build_url)))
+    resp = requests.get(f"{_format_url(build_url)}/consoleText")
     with open("console.log", "w+", encoding="utf-8") as f:
         f.write(str(resp.content.decode("utf-8").split(MAGIC_STRING)[0]))
         f.close()
 
-    resp = requests.get("{}/timestamps?time=HH:mm:ss&appendLog".format(_format_url(build_url)))
+    resp = requests.get(f"{_format_url(build_url)}/timestamps?time=HH:mm:ss&appendLog")
     with open("console-timestamp.log", "w+", encoding="utf-8") as f:
         f.write(str(resp.content.decode("utf-8").split(MAGIC_STRING)[0]))
         f.close()
@@ -605,17 +599,17 @@ def deploy_s3(s3_bucket, s3_path, build_url, workspace, pattern=None):
             file_list.append(file)
 
     log.info("#######################################################")
-    log.info("Deploying files from {} to {}/{}".format(work_dir, s3_bucket, s3_path))
+    log.info(f"Deploying files from {work_dir} to {s3_bucket}/{s3_path}")
 
     # Perform s3 upload
     for file in file_list:
-        log.info("Attempting to upload file {}".format(file))
+        log.info(f"Attempting to upload file {file}")
         if _upload_to_s3(file):
-            log.info("Successfully uploaded {}".format(file))
+            log.info(f"Successfully uploaded {file}")
         else:
-            log.error("FAILURE: Uploading {} failed".format(file))
+            log.error(f"FAILURE: Uploading {file} failed")
 
-    log.info("Finished deploying from {} to {}/{}".format(work_dir, s3_bucket, s3_path))
+    log.info(f"Finished deploying from {work_dir} to {s3_bucket}/{s3_path}")
     log.info("#######################################################")
 
     # Cleanup
@@ -653,20 +647,18 @@ def deploy_nexus_zip(nexus_url, nexus_repo, nexus_path, zip_file):
         tst_path \
         tests/fixtures/deploy/zip-test-files/test.zip
     """
-    url = "{}/service/local/repositories/{}/content-compressed/{}".format(
-        _format_url(nexus_url), nexus_repo, nexus_path
-    )
-    log.debug("Uploading {} to {}".format(zip_file, url))
+    url = f"{_format_url(nexus_url)}/service/local/repositories/{nexus_repo}/content-compressed/{nexus_path}"
+    log.debug(f"Uploading {zip_file} to {url}")
 
     try:
         resp = _request_post_file(url, zip_file)
     except requests.HTTPError as e:
         files = _get_filenames_in_zipfile(zip_file)
-        log.info("Uploading {} failed. It contained the following files".format(zip_file))
+        log.info(f"Uploading {zip_file} failed. It contained the following files")
         for f in files:
-            log.info("   {}".format(f))
-        raise requests.HTTPError(e)
-    log.debug("{}: {}".format(resp.status_code, resp.text))
+            log.info(f"   {f}")
+        raise requests.HTTPError(e) from e
+    log.debug(f"{resp.status_code}: {resp.text}")
 
 
 def nexus_stage_repo_create(nexus_url, staging_profile_id):
@@ -682,9 +674,9 @@ def nexus_stage_repo_create(nexus_url, staging_profile_id):
     Sample:
     lftools deploy nexus-stage-repo-create 192.168.1.26:8081/nexus/ 93fb68073c18
     """
-    nexus_url = "{0}/service/local/staging/profiles/{1}/start".format(_format_url(nexus_url), staging_profile_id)
+    nexus_url = f"{_format_url(nexus_url)}/service/local/staging/profiles/{staging_profile_id}/start"
 
-    log.debug("Nexus URL           = {}".format(nexus_url))
+    log.debug(f"Nexus URL           = {nexus_url}")
 
     xml = """
         <promoteRequest>
@@ -697,24 +689,24 @@ def nexus_stage_repo_create(nexus_url, staging_profile_id):
     headers = {"Content-Type": "application/xml"}
     resp = _request_post(nexus_url, xml, headers)
 
-    log.debug("resp.status_code = {}".format(resp.status_code))
-    log.debug("resp.text = {}".format(resp.text))
+    log.debug(f"resp.status_code = {resp.status_code}")
+    log.debug(f"resp.text = {resp.text}")
 
     if re.search("nexus-error", resp.text):
         error_msg = _get_node_from_xml(resp.text, "msg")
         if re.search(".*profile with id:.*does not exist.", error_msg):
-            _log_error_and_exit("Staging profile id {} not found.".format(staging_profile_id))
+            _log_error_and_exit(f"Staging profile id {staging_profile_id} not found.")
         _log_error_and_exit(error_msg)
 
     if resp.status_code == 405:
         _log_error_and_exit("HTTP method POST is not supported by this URL", nexus_url)
     if resp.status_code == 404:
-        _log_error_and_exit("Did not find nexus site: {}".format(nexus_url))
+        _log_error_and_exit(f"Did not find nexus site: {nexus_url}")
     if not resp.status_code == 201:
-        _log_error_and_exit("Failed with status code {}".format(resp.status_code), resp.text)
+        _log_error_and_exit(f"Failed with status code {resp.status_code}", resp.text)
 
     staging_repo_id = _get_node_from_xml(resp.text, "stagedRepositoryId")
-    log.debug("staging_repo_id = {}".format(staging_repo_id))
+    log.debug(f"staging_repo_id = {staging_repo_id}")
 
     return staging_repo_id
 
@@ -731,27 +723,25 @@ def nexus_stage_repo_close(nexus_url, staging_profile_id, staging_repo_id):
     Sample:
     lftools deploy nexus-stage-repo-close 192.168.1.26:8081/nexsus/ 93fb68073c18 test1-1031
     """
-    nexus_url = "{0}/service/local/staging/profiles/{1}/finish".format(_format_url(nexus_url), staging_profile_id)
+    nexus_url = f"{_format_url(nexus_url)}/service/local/staging/profiles/{staging_profile_id}/finish"
 
-    log.debug("Nexus URL           = {}".format(nexus_url))
-    log.debug("staging_repo_id     = {}".format(staging_repo_id))
+    log.debug(f"Nexus URL           = {nexus_url}")
+    log.debug(f"staging_repo_id     = {staging_repo_id}")
 
-    xml = """
+    xml = f"""
         <promoteRequest>
             <data>
-                <stagedRepositoryId>{0}</stagedRepositoryId>
+                <stagedRepositoryId>{staging_repo_id}</stagedRepositoryId>
                 <description>Close staging repository.</description>
             </data>
         </promoteRequest>
-    """.format(
-        staging_repo_id
-    )
+    """
 
     headers = {"Content-Type": "application/xml"}
     resp = _request_post(nexus_url, xml, headers)
 
-    log.debug("resp.status_code = {}".format(resp.status_code))
-    log.debug("resp.text = {}".format(resp.text))
+    log.debug(f"resp.status_code = {resp.status_code}")
+    log.debug(f"resp.text = {resp.text}")
 
     if re.search("nexus-error", resp.text):
         error_msg = _get_node_from_xml(resp.text, "msg")
@@ -759,7 +749,7 @@ def nexus_stage_repo_close(nexus_url, staging_profile_id, staging_repo_id):
         error_msg = resp.text
 
     if resp.status_code == 404:
-        _log_error_and_exit("Did not find nexus site: {}".format(nexus_url))
+        _log_error_and_exit(f"Did not find nexus site: {nexus_url}")
 
     if re.search("invalid state: closed", error_msg):
         _log_error_and_exit("Staging repository is already closed.")
@@ -767,7 +757,7 @@ def nexus_stage_repo_close(nexus_url, staging_profile_id, staging_repo_id):
         _log_error_and_exit("Staging repository do not exist.")
 
     if not resp.status_code == 201:
-        _log_error_and_exit("Failed with status code {}".format(resp.status_code), resp.text)
+        _log_error_and_exit(f"Failed with status code {resp.status_code}", resp.text)
 
 
 def upload_maven_file_to_nexus(
@@ -795,25 +785,25 @@ def upload_maven_file_to_nexus(
             http://192.168.1.26:8081/nexus/content/repositories/releases \
             tests/fixtures/deploy/zip-test-files
     """
-    url = "{}/service/local/artifact/maven/content".format(_format_url(nexus_url))
+    url = f"{_format_url(nexus_url)}/service/local/artifact/maven/content"
 
-    log.info("Uploading URL: {}".format(url))
+    log.info(f"Uploading URL: {url}")
     params = {}
-    params.update({"r": (None, "{}".format(nexus_repo_id))})
-    params.update({"g": (None, "{}".format(group_id))})
-    params.update({"a": (None, "{}".format(artifact_id))})
-    params.update({"v": (None, "{}".format(version))})
-    params.update({"p": (None, "{}".format(packaging))})
+    params.update({"r": (None, f"{nexus_repo_id}")})
+    params.update({"g": (None, f"{group_id}")})
+    params.update({"a": (None, f"{artifact_id}")})
+    params.update({"v": (None, f"{version}")})
+    params.update({"p": (None, f"{packaging}")})
     if classifier:
-        params.update({"c": (None, "{}".format(classifier))})
+        params.update({"c": (None, f"{classifier}")})
 
-    log.debug("Maven Parameters: {}".format(params))
+    log.debug(f"Maven Parameters: {params}")
 
     resp = _request_post_file(url, file, params)
 
     if re.search("nexus-error", resp.text):
         error_msg = _get_node_from_xml(resp.text, "msg")
-        raise requests.HTTPError("Nexus Error: {}".format(error_msg))
+        raise requests.HTTPError(f"Nexus Error: {error_msg}") from None
 
 
 def deploy_nexus(nexus_repo_url, deploy_dir, snapshot=False, workers=2):
@@ -848,12 +838,12 @@ def deploy_nexus(nexus_repo_url, deploy_dir, snapshot=False, workers=2):
         i = int(math.floor(math.log(bytesize, 1024)))
         p = math.pow(1024, i)
         s = round(bytesize / p, 2)
-        return "{} {}".format(s, suffix[i])
+        return f"{s} {suffix[i]}"
 
     def _deploy_nexus_upload(file):
         # Fix file path, and call _request_put_file.
-        nexus_url_with_file = "{}/{}".format(_format_url(nexus_repo_url), file)
-        log.info("Attempting to upload {} ({})".format(file, _get_filesize(file)))
+        nexus_url_with_file = f"{_format_url(nexus_repo_url)}/{file}"
+        log.info(f"Attempting to upload {file} ({_get_filesize(file)})")
         if _request_put_file(nexus_url_with_file, file):
             return True
         else:
@@ -878,7 +868,7 @@ def deploy_nexus(nexus_repo_url, deploy_dir, snapshot=False, workers=2):
             file_list.append(file)
 
     log.info("#######################################################")
-    log.info("Deploying directory {} to {}".format(deploy_dir, nexus_repo_url))
+    log.info(f"Deploying directory {deploy_dir} to {nexus_repo_url}")
 
     with concurrent.futures.ThreadPoolExecutor(max_workers=workers) as executor:
         # this creates a dict where the key is the Future object, and the value is the file name
@@ -892,18 +882,18 @@ def deploy_nexus(nexus_repo_url, deploy_dir, snapshot=False, workers=2):
                 if data == data:
                     pass
             except Exception as e:
-                log.error("Uploading {}: {}".format(filename, e))
+                log.error(f"Uploading {filename}: {e}")
 
         # wait until all threads complete (successfully or not)
         # then log the results of the upload threads
         concurrent.futures.wait(futures)
         for k, v in futures.items():
             if k.result():
-                log.info("Successfully uploaded {}".format(v))
+                log.info(f"Successfully uploaded {v}")
             else:
-                log.error("FAILURE: Uploading {} failed".format(v))
+                log.error(f"FAILURE: Uploading {v} failed")
 
-    log.info("Finished deploying {} to {}".format(deploy_dir, nexus_repo_url))
+    log.info(f"Finished deploying {deploy_dir} to {nexus_repo_url}")
     log.info("#######################################################")
 
     os.chdir(previous_dir)
@@ -929,17 +919,15 @@ def deploy_nexus_stage(nexus_url, staging_profile_id, deploy_dir):
             Completed uploading files to aaf-1005.
     """
     staging_repo_id = nexus_stage_repo_create(nexus_url, staging_profile_id)
-    log.info("Staging repository {} created.".format(staging_repo_id))
+    log.info(f"Staging repository {staging_repo_id} created.")
 
-    deploy_nexus_url = "{0}/service/local/staging/deployByRepositoryId/{1}".format(
-        _format_url(nexus_url), staging_repo_id
-    )
+    deploy_nexus_url = f"{_format_url(nexus_url)}/service/local/staging/deployByRepositoryId/{staging_repo_id}"
 
     sz_m2repo = sum(os.path.getsize(f) for f in os.listdir(deploy_dir) if os.path.isfile(f))
-    log.debug("Staging repository upload size: {} bytes".format(sz_m2repo))
+    log.debug(f"Staging repository upload size: {sz_m2repo} bytes")
 
-    log.debug("Nexus Staging URL: {}".format(_format_url(deploy_nexus_url)))
+    log.debug(f"Nexus Staging URL: {_format_url(deploy_nexus_url)}")
     deploy_nexus(deploy_nexus_url, deploy_dir)
 
     nexus_stage_repo_close(nexus_url, staging_profile_id, staging_repo_id)
-    log.info("Completed uploading files to {}.".format(staging_repo_id))
+    log.info(f"Completed uploading files to {staging_repo_id}.")
